@@ -373,6 +373,14 @@ window_decorated_notify (MetaWindow *mw,
   meta_window_actor_constructed (G_OBJECT (self));
 }
 
+static void
+window_appears_focused_notify (MetaWindow *mw,
+                               GParamSpec *arg1,
+                               gpointer    data)
+{
+  clutter_actor_queue_redraw (CLUTTER_ACTOR (data));
+}
+
 static void
 meta_window_actor_constructed (GObject *object)
 {
@@ -422,6 +430,8 @@ meta_window_actor_constructed (GObject *object)
 
       g_signal_connect (priv->window, "notify::decorated",
                         G_CALLBACK (window_decorated_notify), self);
+      g_signal_connect (priv->window, "notify::appears-focused",
+                        G_CALLBACK (window_appears_focused_notify), self);
     }
   else
     {
